#include <p24Fxxxx.h>
#include "TLS2130.h"

/*******************************************************************
* FUNCTION:     SwitchPressed() 
* INPUTS:       *sw = Pointer to I/O port register that is connected
*               to switch (e.g. &PORTD)
*               bit = bit number in port that is connected to switch
* OUTPUTS:      TRUE (1) if switch is closed/pressed
*               FALSE (0) if switch is open
* DESCRIPTION:  Tests to see if a switch is pressed.  The routine
*               will debounce the switch press to ensure that it 
*               really is pressed.
* AUTHOR:       Rob Ostapiuk
* DATE:         24 JAN 2008
* REVISIONS:    24 JAN 2008 - Initial Version
*               15 JUN 2008 - Modified to use a pointer like builtins
*******************************************************************/
unsigned SwitchPressed(volatile unsigned int *sw, unsigned bit)
{
    unsigned int count = COUNT;
    
    while ((MIN_COUNT <= count) && (count <= MAX_COUNT))
    {
        if (!(*sw & (1 << bit)))
        {
            count++;
            if (count > MAX_COUNT)
            {
                count = MAX_COUNT;
                return 1;
            }
        }
        else
        {
            count--;
            if (count < MIN_COUNT)
            {
                count = MIN_COUNT;
                return 0;
            }
        }
    }
    return 0;  //Should never reach this point - return should always happen within while loop
               //This was added to eliminate the warning:
               //warning: control reaches end of non-void function
}
