#include <p24Fxxxx.h>
#include "TLS2130.h"
#include "lcdLib.h"

/*******************************************************************
* FUNCTION:     lcdPutFloat() 
* INPUTS:       num = integer number to display
*               precision = desired number of decimal places
* OUTPUTS:      None
* DESCRIPTION:  Writes a number to LCD at current cursor position
* AUTHOR:       Rob Ostapiuk
* DATE:         24 JAN 2008
* REVISIONS:    24 JAN 2008 - Initial Version
*******************************************************************/
void lcdPutFloat(float fnum, char precision)
{
    int i;                  // Loop index variable
    unsigned char digits[MAX_DIGITS];// Array to hold individual digits
                            // NOTE: digits stored in reverse order
                            // LSD is stored in digits[0]
    long num;               // Holds long integer version of fnum
    
    // If number is zero, simply display a zero and return
    if (fnum == 0)
    {
        lcdPutChar('0');
        return;
    }
    
    // Multiply by 10 until all desired decimal places are on left of
    // the decimal point
    i = precision;
    while (i > 0)
    {
        fnum *= 10;
        i--;
    }
    num = (long)fnum;
    
    // If number is negative, display minus sign and invert the
    // sign of num for conversion
    if (num < 0) 
    {
        num = -num;
        lcdPutChar('-');
    }
        
    // Break up number into its individual digits
    // and clear unused elements of digits array
    for (i=0; i<MAX_DIGITS; i++)
    {
        digits[i] = 0;
        if (num == 0) continue;
        digits[i] = (char)(num % 10);
        num /= 10;
    }
    
    // Display the digits...
    // Setup loop index to end of array and work back to front
    i = MAX_DIGITS-1;
    
    while (digits[i] == 0) i--;  // Skip leading zeros
    
    while (i >= 0)
    {
        // Insert decimal point for desired precision
        if (i == (precision-1))
            lcdPutChar('.');
           
        // Send ASCII value of digit to display
        lcdPutChar(digits[i]+48);
            
        // Move to next digit
        i--;
    }
} 
